@@ -33,7 +33,7 @@ gmc_unable_to_execute_dlg (gchar *fname, const gchar *command, gchar *action, co
 			_("Unable to execute\n\"%s\".\n\n"
 			"Please check it to see if it points to a valid command."),
 			fname);
-		
+
 	} else {
 		if (mime)
 			fix = g_strdup_printf (
@@ -41,7 +41,7 @@ gmc_unable_to_execute_dlg (gchar *fname, const gchar *command, gchar *action, co
 				"in the GNOME Control Center, and edit the default %s"
 				"-action for \"%s\"."),
 				action, mime);
-		else 
+		else
 			fix = g_strdup_printf (
 				_("\".\n\nTo fix this error, bring up this file's properties "
 				"and change the default %s-action."),
@@ -50,7 +50,7 @@ gmc_unable_to_execute_dlg (gchar *fname, const gchar *command, gchar *action, co
 		msg = g_strdup_printf (
 			_("Unable to %s\n\"%s\"\nwith the command:\n\"%s\"%s"),
 			action, fname, command, fix);
-			
+
 		g_free (fix);
 	}
 	msg_dialog = gnome_message_box_new (msg,
@@ -81,7 +81,7 @@ gmc_check_exec_string (const char *buf)
 	gint retval, i;
 	gchar *prog;
 	gchar **argv;
-	
+
 	gnome_config_make_vector (buf, &argc, &argv);
 	if (argc < 1)
 		return FALSE;
@@ -103,13 +103,19 @@ gmc_check_exec_string (const char *buf)
 int
 gmc_open_filename (char *fname, GList *args)
 {
+	/* fname is a full name */
+
 	const char *mime_type;
 	const char *cmd;
 	char *buf = NULL;
 	int size;
 	int needs_terminal = 0;
 
-	mime_type = gnome_mime_type_or_default (fname, NULL);
+	if (use_magic)
+		mime_type = gnome_mime_type_or_default_of_file (fname, NULL);
+	else
+		mime_type = gnome_mime_type_or_default (fname, NULL);
+
 	/*
 	 * We accept needs_terminal as -1, which means our caller
 	 * did not want to do the work
@@ -117,16 +123,13 @@ gmc_open_filename (char *fname, GList *args)
 	if (gnome_metadata_get (fname, "flags", &size, &buf) == 0){
 		needs_terminal = (strstr (buf, "needsterminal") != 0);
 		g_free (buf);
-	} else if (mime_type){
-		const char *flags;
-		
-		flags = gnome_mime_type_or_default (mime_type, "flags");
-		needs_terminal = (strstr (flags, "needsterminal") != 0);
-	}
-	
-	if (gnome_metadata_get (fname, "fm-open", &size, &buf) != 0) {
+		buf = NULL;
+	} else if (mime_type)
+		needs_terminal = gnome_mime_needsterminal (mime_type, "open.flags");
+
+	if (gnome_metadata_get (fname, "fm-open", &size, &buf) != 0)
 		gnome_metadata_get (fname, "open", &size, &buf);
-	}
+
 	if (buf) {
 		if (gmc_check_exec_string (buf))
 			gmc_execute (fname, buf, needs_terminal);
@@ -135,26 +138,29 @@ gmc_open_filename (char *fname, GList *args)
 		g_free (buf);
 		return 1;
 	}
+
 	if (!mime_type)
 		return 0;
-	
+
 	cmd = gnome_mime_get_value (mime_type, "fm-open");
 	if (cmd == NULL) {
 		cmd = gnome_mime_get_value (mime_type, "open");
 	}
-	
+
 	if (cmd){
 		if (gmc_check_exec_string (cmd))
 			gmc_execute (fname, cmd, needs_terminal);
-		else 
+		else
 			gmc_unable_to_execute_dlg (fname, cmd, _("open"), mime_type);
 		return 1;
 	}
 
-	if (strcmp (mime_type, "application/x-gnome-app-info")  == 0){
+	if ((strcmp (mime_type, "application/x-gnome-app-info")  == 0) ||
+	    (strcmp (mime_type, "application/x-kde-app-info")  == 0)){
 		GnomeDesktopEntry *entry;
 
 		entry = gnome_desktop_entry_load (fname);
+
 		if (entry){
 			gnome_desktop_entry_launch (entry);
 			gnome_desktop_entry_free (entry);
@@ -164,6 +170,7 @@ gmc_open_filename (char *fname, GList *args)
 			return 1;
 		}
 	}
+
 	/* We just struck out.  Prompt the user. */
 	return 0;
 }
@@ -171,6 +178,8 @@ gmc_open_filename (char *fname, GList *args)
 int
 gmc_edit (char *fname)
 {
+	/* fname is a full path */
+
 	const char *mime_type;
 	const char *cmd;
 	char *buf;
@@ -187,10 +196,14 @@ gmc_edit (char *fname)
 		return 1;
 	}
 
-	mime_type = gnome_mime_type_or_default (fname, NULL);
+	if (use_magic)
+		mime_type = gnome_mime_type_or_default_of_file (fname, NULL);
+	else
+		mime_type = gnome_mime_type_or_default (fname, NULL);
+
 	if (mime_type){
 		cmd = gnome_mime_get_value (mime_type, "edit");
-	
+
 		if (cmd){
 			if (gmc_check_exec_string (cmd))
 				gmc_execute (fname, cmd, 0);
@@ -202,7 +215,7 @@ gmc_edit (char *fname)
 
 	gnome_config_push_prefix( "/editor/Editor/");
 	type = gnome_config_get_string ("EDITOR_TYPE=executable");
-	
+
 	if (strcmp (type, "mc-internal") == 0){
 		g_free (type);
 		do_edit (fname);
@@ -216,13 +229,13 @@ gmc_edit (char *fname)
 	if (on_terminal){
 		char *quoted = name_quote (fname, 0);
 		char *editor_cmd = g_strconcat (editor, " ", quoted, NULL);
-		
+
 		gnome_open_terminal_with_cmd (editor_cmd);
 		g_free (quoted);
 		g_free (editor_cmd);
 	} else {
 		char *cmd = g_strconcat (editor, " %s", NULL);
-		
+
 		gmc_execute (fname, cmd, 0);
 		g_free (cmd);
 	}
@@ -300,29 +313,36 @@ gmc_view_command (gchar *filename)
 	if (gnome_metadata_get (filename, "view", &size, &buf) == 0)
 		return buf;
 
-	mime_type = gnome_mime_type_or_default (filename, NULL);
+	if (use_magic)
+		mime_type = gnome_mime_type_or_default_of_file (filename, NULL);
+	else
+		mime_type = gnome_mime_type_or_default (filename, NULL);
+
 	if (!mime_type)
 		return NULL;
-	
-		
+
+
 	cmd = gnome_mime_get_value (mime_type, "fm-view");
-	
+
 	if (cmd)
 		return g_strdup (cmd);
-	
+
 	cmd = gnome_mime_get_value (mime_type, "view");
 	if (cmd){
 		return g_strdup (cmd);
 	}
 	return NULL;
 }
-	
+
 int
 gmc_view (char *filename, int start_line)
 {
 	gchar *cmd;
 	const gchar *mime_type;
-	mime_type = gnome_mime_type_or_default (filename, NULL);
+	if (use_magic)
+		mime_type = gnome_mime_type_or_default_of_file (filename, NULL);
+	else
+		mime_type = gnome_mime_type_or_default (filename, NULL);
 	cmd = gmc_view_command (filename);
 	if (cmd) {
 		if (gmc_check_exec_string (cmd))
