@@ -10,6 +10,7 @@
 #define GDESKTOP_H
 
 #include "dir.h"
+#include "gcmd.h"
 
 
 /* Snap granularity for desktop icons -- maybe these should be calculated in
@@ -73,6 +74,7 @@ gboolean    do_eject (char *filename);
 void desktop_rescan_devices (void);
 void desktop_recreate_default_icons (void);
 void desktop_reload_icons (int user_pos, int xpos, int ypos);
+void desktop_arrange_icons (SortType type);
 void desktop_create_url (const char *filename, const char *title, const char *url, const char *icon);
 
 extern int desktop_wm_is_gnome_compliant;
