@@ -11,24 +11,17 @@
 
 /* The current versions only work in the forward direction only!! */
       
+#include "config.h"
+
 #include <stdio.h>
+
+
 #include "slang.h"
 #include "_slang.h"
 
-void jed_memset(char *p, char space, int n)
+void SLmemset(char *p, char space, int n)
 {
-#if !defined(msdos) || defined(__WIN32__)
-   register char *pmax;
-
-   pmax = p + (n - 4);
-   n = n % 4;
-   while(p <= pmax) 
-     {
-	*p = space; *(p + 1) = space; *(p + 2) = space; *(p + 3) = space;
-	p += 4;
-     }
-   while (n--) *p++ = space;
-#else
+#if defined(msdos) && !defined(__WIN32__) && !defined(__GO32__)
    asm mov al, space
    asm mov dx, di
    asm mov cx, n
@@ -36,5 +29,15 @@ void jed_memset(char *p, char space, int n)
    asm cld
    asm rep stosb
    asm mov di, dx
+#else
+   register char *pmax;
+
+   pmax = p + (n - 4);
+   n = n % 4;
+   while (p <= pmax) 
+     {
+	*p++ = space; *p++ = space; *p++ = space; *p++= space;
+     }
+   while (n--) *p++ = space;     
 #endif
 }
