@@ -73,7 +73,7 @@
 
 #include "x.h"
 
-/* "$Id: layout.c,v 1.18 1999/04/06 19:00:32 unammx Exp $" */
+/* "$Id: layout.c,v 1.19 1999/11/03 12:50:54 pavel Exp $" */
 
 /* Controls the display of the rotating dash on the verbose mode */
 int nice_rotating_dash = 1;
@@ -856,9 +856,22 @@ void print_vfs_message (char *msg, ...)
     g_vsnprintf (str, 126, msg, ap);
     va_end (ap);
     
-    if (midnight_shutdown || !the_hint || !the_hint->widget.parent)
+    if (midnight_shutdown)
 	return;
-    
+
+    if (!message_visible || !the_hint || !the_hint->widget.parent) {
+        int i;
+
+	if (!nice_rotating_dash || (ok_to_refresh <= 0))
+	    return;
+	move (0, 0);
+	printw (str);
+	for (i=strlen(str); i<COLS-1; i++)
+	    printw (" ");
+	mc_refresh ();
+	return;
+    }
+
     if (message_visible || (xterm_flag && xterm_hintbar)) {
         set_hintbar(str);
     }
