@@ -7,7 +7,7 @@
 	       1997 Norbert Warmuth
 	       1998 Pavel Machek
 
-   $Id: ftpfs.c,v 1.61 2000/04/03 10:35:48 pavel Exp $   
+   $Id: ftpfs.c,v 1.66 2000/04/28 07:43:13 pavel Exp $   
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License
@@ -81,6 +81,7 @@ What to do with this?
 #include "vfs.h"
 #include "tcputil.h"
 #include "../src/dialog.h"
+#include "../src/setup.h"	/* for load_anon_passwd */
 #include "container.h"
 #include "ftpfs.h"
 #ifndef MAXHOSTNAMELEN
@@ -117,7 +118,7 @@ extern char *home_dir;
 
 /* Anonymous setup */
 char *ftpfs_anonymous_passwd = NULL;
-int ftpfs_directory_timeout;
+int ftpfs_directory_timeout = 900;
 
 /* Proxy host */
 char *ftpfs_proxy_host = NULL;
@@ -221,7 +222,7 @@ my_get_host_and_username (char *path, char **host, char **user, int *port, char
 static int
 get_reply (vfs *me, int sock, char *string_buf, int string_len)
 {
-    char answer[1024];
+    char answer[BUF_1K];
     int i;
     
     for (;;) {
@@ -356,7 +357,7 @@ login_server (vfs *me, vfs_s_super *super, char *netrcpass)
     char *op;
     char *name;			/* login user name */
     int  anon = 0;
-    char reply_string[255];
+    char reply_string[BUF_MEDIUM];
 
     SUP.isbinary = TYPE_UNKNOWN;    
     if (netrcpass)
@@ -574,7 +575,7 @@ load_no_proxy_list ()
 }
 
 static int
-ftpfs_check_proxy (char *host)
+ftpfs_check_proxy (const char *host)
 {
     struct no_proxy_entry	*npe;
 
@@ -616,17 +617,15 @@ ftpfs_check_proxy (char *host)
 static void
 ftpfs_get_proxy_host_and_port (char *proxy, char **host, int *port)
 {
-    char *user, *pass, *dir;
+    char *user, *dir;
 
 #if defined(HSC_PROXY)
-    dir = vfs_split_url (proxy, host, &user, port, &pass, HSC_PROXY_PORT, URL_DEFAULTANON);
+    dir = vfs_split_url (proxy, host, &user, port, 0, HSC_PROXY_PORT, URL_DEFAULTANON);
 #else
-    dir = vfs_split_url (proxy, host, &user, port, &pass, FTP_COMMAND_PORT, URL_DEFAULTANON);
+    dir = vfs_split_url (proxy, host, &user, port, 0, FTP_COMMAND_PORT, URL_DEFAULTANON);
 #endif
 
     g_free (user);
-    if (pass)
-	wipe_password (pass);
     if (dir)
 	g_free (dir);
 }
@@ -767,10 +766,13 @@ open_archive (vfs *me, vfs_s_super *super, char *archive_name, char *op)
     char *host, *user, *password;
     int port;
 
-    vfs_split_url (strchr(op, ':')+1, &host, &user, &port, &password, FTP_COMMAND_PORT, URL_DEFAULTANON);
+    op = vfs_split_url (strchr(op, ':')+1, &host, &user, &port, &password, FTP_COMMAND_PORT, URL_DEFAULTANON);
 
-    SUP.host = g_strdup (host);
-    SUP.user = g_strdup (user);
+    if (op)
+	g_free (op);
+
+    SUP.host = host;
+    SUP.user = user;
     SUP.port = port;
     SUP.home = NULL;
     SUP.proxy= 0;
@@ -783,23 +785,33 @@ open_archive (vfs *me, vfs_s_super *super, char *archive_name, char *op)
     SUP.remote_is_amiga = 0;
     super->name = g_strdup("/");
 #if 0
-    super->name = g_strconcat( "/#ftp:", SUP.user, "@", SUP.host, "/", NULL );
+    super->name = g_strconcat( "/#ftp:", user, "@", host, "/", NULL );
 #endif
     super->root = vfs_s_new_inode (me, super, vfs_s_default_stat(me, S_IFDIR | 0755)); 
     if (password)
-	SUP.password = g_strdup (password);
+	SUP.password = password;
     return open_archive_int (me, super);
 }
 
 static int
 archive_same(vfs *me, vfs_s_super *super, char *archive_name, char *op, void *cookie)
 {	
-    char *host, *user, *dummy2;
+    char *host, *user;
     int port;
-    vfs_split_url (strchr(op, ':')+1, &host, &user, &port, &dummy2, 21, URL_DEFAULTANON);
-    return ((strcmp (host, SUP.host) == 0) &&
+
+    op = vfs_split_url (strchr(op, ':')+1, &host, &user, &port, 0, 21, URL_DEFAULTANON);
+
+    if (op)
+	g_free (op);
+
+    port = ((strcmp (host, SUP.host) == 0) &&
 	    (strcmp (user, SUP.user) == 0) &&
 	    (port == SUP.port));
+
+    g_free (host);
+    g_free (user);
+
+    return port;
 }
 
 static int
@@ -821,7 +833,7 @@ dir_uptodate(vfs *me, vfs_s_inode *ino)
 static char *
 ftpfs_get_current_directory (vfs *me, vfs_s_super *super)
 {
-    char buf[4096], *bufp, *bufq;
+    char buf[BUF_8K], *bufp, *bufq;
 
     if (command (me, super, NONE, "PWD") == COMPLETE &&
         get_reply(me, SUP.sock, buf, sizeof(buf)) == COMPLETE) {
@@ -1169,7 +1181,8 @@ dir_load(vfs *me, vfs_s_inode *dir, char *remote_path)
     vfs_s_entry *ent;
     vfs_s_super *super = dir->super;
     int sock, has_symlinks = 0, num_entries = 0;
-    char buffer[8192];
+    char buffer[BUF_8K];
+    
     int cd_first = (strchr (remote_path, ' ') != NULL) || ftpfs_first_cd_then_ls || (SUP.strict == RFC_STRICT);
 
     print_vfs_message(_("ftpfs: Reading FTP directory %s... %s%s"), remote_path, 
@@ -1178,8 +1191,9 @@ dir_load(vfs *me, vfs_s_inode *dir, char *remote_path)
 
     if (cd_first) {
         char *p;
-    
+
         p = translate_path (me, super, remote_path);
+
         if (ftpfs_chdir_internal (me, super, p) != COMPLETE) {
 	    g_free (p);
             my_errno = ENOENT;
@@ -1195,7 +1209,8 @@ dir_load(vfs *me, vfs_s_inode *dir, char *remote_path)
     if (SUP.strict == RFC_STRICT) 
         sock = open_data_connection (me, super, "LIST", 0, TYPE_ASCII, 0);
     else if (cd_first)
-        sock = open_data_connection (me, super, "LIST -la", ".", TYPE_ASCII, 0);
+	/* Dirty hack to avoid autoprepending / to . */
+        sock = open_data_connection (me, super, "LIST -la .", 0, TYPE_ASCII, 0);
     else {
 	/* Trailing "/." is necessary if remote_path is a symlink
            but don't generate "//." */
@@ -1239,6 +1254,7 @@ dir_load(vfs *me, vfs_s_inode *dir, char *remote_path)
 	}
 	num_entries++;
 	if ((!strcmp(ent->name, ".")) || (!strcmp (ent->name, ".."))) {
+	    g_free (ent->name);
 	    ent->name = NULL;	/* Ouch, vfs_s_free_entry "knows" about . and .. being special :-( */
 	    vfs_s_free_entry (me, ent);
 	    continue;
@@ -1368,6 +1384,7 @@ linear_start(vfs *me, vfs_s_fh *fh, int offset)
     if (!name)
 	return 0;
     FH_SOCK = open_data_connection(me, FH_SUPER, "RETR", name, TYPE_BINARY, offset);
+    g_free (name);
     if (FH_SOCK == -1)
 	ERRNOR (EACCES, 0);
     fh->linear = LS_LINEAR_OPEN;
@@ -1812,11 +1829,12 @@ int lookup_netrc (char *host, char **login, char **pass)
 	while ((keyword = netrc_next ()) > 2) {
 	    switch (keyword) {
 		case 3:
-		    if (netrc_next ())
+		    if (netrc_next ()) {
 			if (*login == NULL)
 			    *login = g_strdup (buffer);
 			else if (strcmp (*login, buffer))
 			    keyword = 20;
+		    }
 		    break;
 		case 4:
 		case 5:
@@ -1846,11 +1864,13 @@ int lookup_netrc (char *host, char **login, char **pass)
 	    if (keyword == 20)
 	        break;
 	}
-	if (keyword == 20)
-	    continue;
-	else
+	if (keyword != 20)
 	    break;
     }
+
+    g_free (netrc);
+    g_free (netrcname);
+
     rupp = g_new (struct rupcache, 1);
     rupp->host = g_strdup (host);
     rupp->login = rupp->pass = 0;
@@ -1862,8 +1882,6 @@ int lookup_netrc (char *host, char **login, char **pass)
     rupp->next = rup_cache;
     rup_cache = rupp;
     
-    g_free (netrc);
-    g_free (netrcname);
     return 0;
 }
 
